@@ -48,7 +48,7 @@ struct Pg_dir_state => {
 };
 
 use constant {
-    VERSIONNUM       => "14.1",
+    VERSIONNUM       => "15.0",
     VERSIONINFO      => "[0] (pg-rex_operation_tools) [1]\n",
     CONFIG_PATH      => "/etc/",
     CONFIG_FILENAME  => "pg-rex_tools.conf",
@@ -111,8 +111,7 @@ sub pacemaker_online{
     # Pacemaker が Online だったら1を返却する
     foreach my $line (@crm_results){
         # pcs status --full の結果に「Online: [ ～ <マシンのホスト名>」の行が存在すると OK
-        if ($line =~ /Online\:\s+\[(\s+\S+)?\s.*$my_node\s+/
-            || $line =~ /Node $my_node .*: online,/){
+        if ($line =~ /Online\:\s+\[(\s+\S+)?\s.*$my_node\s+/){
             return 1;
         }
     }
@@ -909,7 +908,7 @@ sub check_support_version {
 
     # PostgreSQL がサポート対象バージョンであるかを確認する
     $version_num = get_pg_version_num($postgres_path, $exec_user);
-    if (int($version_num / 10000) != 14){
+    if (int($version_num / 10000) != 15){
         if ($version_num >= 100000) {
             printlog("ERROR", COMMON_MS0037, int($version_num / 10000));
         } else {
